Mask class

Constructors

Mask()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

validations → Validations
no setter

Static Methods

cnpj() → TextInputFormatter
use to format cnpj fields
cpf() → TextInputFormatter
use to format cpf fields
cpfOrCnpj() → TextInputFormatter
use to format cpfOrCnpj fields
creditCard() → TextInputFormatter
use to format creditCard fields
date() → TextInputFormatter
use to format date fields
generic({required List<String> masks, Hashtag hashtag = Hashtag.numbers}) → TextInputFormatter
use to format date fields
money({int decimalLenght = 2, String decimal = '.', String fracion = ',', String moneySymbol = r'R$'}) → TextInputFormatter
use to format money fields
phone() → TextInputFormatter
use to format phone fields